@@ -115,8 +115,7 @@ def _receivers(dev_path=None):
 
 
 def _receivers_and_devices(dev_path=None):
-    from logitech_receiver import Device
-    from logitech_receiver import Receiver
+    from logitech_receiver import Device, Receiver
     from logitech_receiver.base import receivers_and_devices
     for dev_info in receivers_and_devices():
         if dev_path is not None and dev_path != dev_info.path:
@@ -204,7 +203,9 @@ def run(cli_args=None, hidraw_path=None):
         else:
             c = list(_receivers(hidraw_path))
         if not c:
-            raise Exception('No devices found')
+            raise Exception(
+                'No supported device found.  Use "lsusb" and "bluetoothctl devices Connected" to list connected devices.'
+            )
         from importlib import import_module
         m = import_module('.' + action, package=__name__)
         m.run(c, args, _find_receiver, _find_device)
